@@ -61,6 +61,7 @@
 #include <libxfdashboard/plugins-manager.h>
 #include <libxfdashboard/marshal.h>
 #include <libxfdashboard/compat.h>
+#include <libxfdashboard/debug.h>
 
 
 /* Define this class in GObject system */
@@ -82,6 +83,7 @@ struct _XfdashboardApplicationPrivate
 	/* Instance related */
 	gboolean						initialized;
 	gboolean						isQuitting;
+	gboolean						forcedNewInstance;
 
 	XfconfChannel					*xfconfChannel;
 	XfdashboardStage				*stage;
@@ -251,7 +253,7 @@ static void _xfdashboard_application_on_session_quit(XfdashboardApplication *sel
 	g_return_if_fail(XFCE_IS_SM_CLIENT(inUserData));
 
 	/* Force application to quit */
-	g_debug("Received 'quit' from session management client - initiating shutdown");
+	XFDASHBOARD_DEBUG(self, MISC, "Received 'quit' from session management client - initiating shutdown");
 	_xfdashboard_application_quit(self, TRUE);
 }
 
@@ -371,7 +373,7 @@ static gboolean _xfdashboard_application_initialize_full(XfdashboardApplication
 
 	/* Setup the session management */
 	sessionManagementRestartStyle=XFCE_SM_CLIENT_RESTART_IMMEDIATELY;
-	if(g_getenv("XFDASHBOARD_FORCE_NEW_INSTANCE")) sessionManagementRestartStyle=XFCE_SM_CLIENT_RESTART_NORMAL;
+	if(priv->forcedNewInstance) sessionManagementRestartStyle=XFCE_SM_CLIENT_RESTART_NORMAL;
 
 	priv->sessionManagementClient=xfce_sm_client_get();
 	xfce_sm_client_set_priority(priv->sessionManagementClient, XFCE_SM_CLIENT_PRIORITY_DEFAULT);
@@ -533,12 +535,14 @@ static void _xfdashboard_application_switch_to_view(XfdashboardApplication *self
 	if(!inInternalViewName ||
 		!inInternalViewName[0])
 	{
-		g_debug("No view to switch to specified");
+		XFDASHBOARD_DEBUG(self, MISC, "No view to switch to specified");
 		return;
 	}
 
 	/* Tell stage to switch requested view */
-	g_debug("Trying to switch to view '%s'", inInternalViewName);
+	XFDASHBOARD_DEBUG(self, MISC,
+						"Trying to switch to view '%s'",
+						inInternalViewName);
 	xfdashboard_stage_set_switch_to_view(priv->stage, inInternalViewName);
 }
 
@@ -562,7 +566,7 @@ static gint _xfdashboard_application_handle_command_line_arguments(XfdashboardAp
 										{ "quit", 'q', 0, G_OPTION_ARG_NONE, &optionQuit, N_("Quit running instance"), NULL },
 										{ "restart", 'r', 0, G_OPTION_ARG_NONE, &optionRestart, N_("Restart running instance"), NULL },
 										{ "toggle", 't', 0, G_OPTION_ARG_NONE, &optionToggle, N_("Toggles visibility if running instance was started in daemon mode otherwise it quits running non-daemon instance"), NULL },
-										{ "view", 0, 0, G_OPTION_ARG_STRING, &optionSwitchToView, N_("The view to switch to on startup or resume"), NULL },
+										{ "view", 0, 0, G_OPTION_ARG_STRING, &optionSwitchToView, N_("The ID of view to switch to on startup or resume"), "ID" },
 										{ NULL }
 									};
 
@@ -579,19 +583,19 @@ static gint _xfdashboard_application_handle_command_line_arguments(XfdashboardAp
 	optionSwitchToView=NULL;
 
 	/* Setup command-line options */
-	context=g_option_context_new(N_("- A Gnome Shell like dashboard for Xfce4"));
+	context=g_option_context_new(N_(""));
+	g_option_context_set_summary(context, N_("A Gnome Shell like dashboard for Xfce4 - version " PACKAGE_VERSION));
+	g_option_context_set_translation_domain(context, GETTEXT_PACKAGE);
 	g_option_context_add_group(context, gtk_get_option_group(TRUE));
 	g_option_context_add_group(context, clutter_get_option_group_without_init());
 	g_option_context_add_group(context, xfce_sm_client_get_option_group(inArgc, inArgv));
 	g_option_context_add_main_entries(context, entries, GETTEXT_PACKAGE);
 
 #ifdef DEBUG
-	/* I always forget the name of the environment variable to get the debug
-	 * message display which are emitted with g_debug(). So display a hint
-	 * if application was compiled with debug enabled.
-	 */
-	g_print("** To get debug messages set environment variable G_MESSAGES_DEBUG to %s\n", PACKAGE_NAME);
-	g_print("** e.g.: G_MESSAGES_DEBUG=%s %s\n", PACKAGE_NAME, inArgv[0]);
+#ifdef XFDASHBOARD_ENABLE_DEBUG
+	g_print("** Use environment variable XFDASHBOARD_DEBUG to enable debug messages\n");
+	g_print("** To get a list of debug categories set XFDASHBOARD_DEBUG=help\n");
+#endif
 #endif
 
 	if(!g_option_context_parse(context, &inArgc, &inArgv, &error))
@@ -612,6 +616,51 @@ static gint _xfdashboard_application_handle_command_line_arguments(XfdashboardAp
 		return(XFDASHBOARD_APPLICATION_ERROR_FAILED);
 	}
 
+	/* Set up debug flags */
+#ifdef XFDASHBOARD_ENABLE_DEBUG
+	{
+		const gchar					*environment;
+		static const GDebugKey		debugKeys[]=
+									{
+										{ "misc", XFDASHBOARD_DEBUG_MISC },
+										{ "actor", XFDASHBOARD_DEBUG_ACTOR },
+										{ "style", XFDASHBOARD_DEBUG_STYLE },
+										{ "styling", XFDASHBOARD_DEBUG_STYLE },
+										{ "theme", XFDASHBOARD_DEBUG_THEME },
+										{ "apps", XFDASHBOARD_DEBUG_APPLICATIONS },
+										{ "applications", XFDASHBOARD_DEBUG_APPLICATIONS },
+										{ "images", XFDASHBOARD_DEBUG_IMAGES },
+										{ "windows", XFDASHBOARD_DEBUG_WINDOWS },
+										{ "window-tracker", XFDASHBOARD_DEBUG_WINDOWS },
+									};
+
+		/* Parse debug flags */
+		environment=g_getenv("XFDASHBOARD_DEBUG");
+		if(environment)
+		{
+			xfdashboard_debug_flags=
+				g_parse_debug_string(environment,
+										debugKeys,
+										G_N_ELEMENTS(debugKeys));
+			environment=NULL;
+		}
+
+		/* Parse object names to debug */
+		environment=g_getenv("XFDASHBOARD_DEBUG");
+		if(environment)
+		{
+			if(G_UNLIKELY(xfdashboard_debug_classes))
+			{
+				g_strfreev(xfdashboard_debug_classes);
+				xfdashboard_debug_classes=NULL;
+			}
+
+			xfdashboard_debug_classes=g_strsplit(environment, ",", -1);
+			environment=NULL;
+		}
+	}
+#endif
+
 	/* If this application instance is a remote instance do not handle any
 	 * command-line argument. The arguments will be sent to the primary instance,
 	 * handled there and the exit code will be sent back to the remote instance.
@@ -621,7 +670,7 @@ static gint _xfdashboard_application_handle_command_line_arguments(XfdashboardAp
 	 */
 	if(g_application_get_is_remote(G_APPLICATION(self)))
 	{
-		g_debug("Do not handle command-line parameters on remote application instance");
+		XFDASHBOARD_DEBUG(self, MISC, "Do not handle command-line parameters on remote application instance");
 
 		/* Release allocated resources */
 		if(optionSwitchToView) g_free(optionSwitchToView);
@@ -632,7 +681,7 @@ static gint _xfdashboard_application_handle_command_line_arguments(XfdashboardAp
 		 */
 		return(XFDASHBOARD_APPLICATION_ERROR_NONE);
 	}
-	g_debug("Handling command-line parameters on primary application instance");
+	XFDASHBOARD_DEBUG(self, MISC, "Handling command-line parameters on primary application instance");
 
 	/* Handle options: restart
 	 *
@@ -645,7 +694,7 @@ static gint _xfdashboard_application_handle_command_line_arguments(XfdashboardAp
 		priv->initialized)
 	{
 		/* Quit existing instance for restart */
-		g_debug("Received request to restart application!");
+		XFDASHBOARD_DEBUG(self, MISC, "Received request to restart application!");
 		_xfdashboard_application_quit(self, TRUE);
 
 		/* Release allocated resources */
@@ -665,7 +714,7 @@ static gint _xfdashboard_application_handle_command_line_arguments(XfdashboardAp
 	if(optionQuit)
 	{
 		/* Quit existing instance */
-		g_debug("Received request to quit running instance!");
+		XFDASHBOARD_DEBUG(self, MISC, "Received request to quit running instance!");
 		_xfdashboard_application_quit(self, TRUE);
 
 		/* Release allocated resources */
@@ -723,18 +772,27 @@ static gint _xfdashboard_application_handle_command_line_arguments(XfdashboardAp
 	 * Check if application shoud run in daemon mode. A daemonized instance runs in
 	 * background and does not present the stage initially. The application must not
 	 * be initialized yet as it can only be done on start-up.
+	 *
+	 * Does not work if a new instance was forced.
 	 */
 	if(optionDaemonize &&
 		!priv->initialized)
 	{
-		priv->isDaemon=optionDaemonize;
-		g_object_notify_by_pspec(G_OBJECT(self), XfdashboardApplicationProperties[PROP_DAEMONIZED]);
-
-		if(priv->isDaemon)
+		if(!priv->forcedNewInstance)
 		{
-			priv->isSuspended=TRUE;
-			g_object_notify_by_pspec(G_OBJECT(self), XfdashboardApplicationProperties[PROP_SUSPENDED]);
+			priv->isDaemon=optionDaemonize;
+			g_object_notify_by_pspec(G_OBJECT(self), XfdashboardApplicationProperties[PROP_DAEMONIZED]);
+
+			if(priv->isDaemon)
+			{
+				priv->isSuspended=TRUE;
+				g_object_notify_by_pspec(G_OBJECT(self), XfdashboardApplicationProperties[PROP_SUSPENDED]);
+			}
 		}
+			else
+			{
+				g_warning(_("Cannot daemonized because a temporary new instance of application was forced."));
+			}
 	}
 
 	/* Check if this instance needs to be initialized fully */
@@ -1357,7 +1415,7 @@ static void xfdashboard_application_class_init(XfdashboardApplicationClass *klas
 						G_STRUCT_OFFSET(XfdashboardApplicationClass, exit),
 						g_signal_accumulator_true_handled,
 						NULL,
-						_xfdashboard_marshal_BOOLEAN__OBJECT_STRING_OBJECT,
+						_xfdashboard_marshal_BOOLEAN__OBJECT_STRING_BOXED,
 						G_TYPE_BOOLEAN,
 						3,
 						XFDASHBOARD_TYPE_FOCUSABLE,
@@ -1393,6 +1451,7 @@ static void xfdashboard_application_init(XfdashboardApplication *self)
 	priv->isQuitting=FALSE;
 	priv->sessionManagementClient=NULL;
 	priv->pluginManager=NULL;
+	priv->forcedNewInstance=FALSE;
 
 	/* Add callable DBUS actions for this application */
 	action=g_simple_action_new("Quit", NULL);
@@ -1438,6 +1497,11 @@ XfdashboardApplication* xfdashboard_application_get_default(void)
 												"flags", G_APPLICATION_HANDLES_COMMAND_LINE,
 												NULL);
 
+		if(forceNewInstance)
+		{
+			_xfdashboard_application->priv->forcedNewInstance=TRUE;
+		}
+
 		/* Release allocated resources */
 		if(appID) g_free(appID);
 	}
