@@ -87,6 +87,14 @@ struct _XfdashboardFocusableInterface
 											XfdashboardFocusable *inSource,
 											const gchar *inAction,
 											ClutterEvent *inEvent);
+	gboolean (*selection_move_next)(XfdashboardFocusable *self,
+											XfdashboardFocusable *inSource,
+											const gchar *inAction,
+											ClutterEvent *inEvent);
+	gboolean (*selection_move_previous)(XfdashboardFocusable *self,
+											XfdashboardFocusable *inSource,
+											const gchar *inAction,
+											ClutterEvent *inEvent);
 	gboolean (*selection_move_page_left)(XfdashboardFocusable *self,
 											XfdashboardFocusable *inSource,
 											const gchar *inAction,
@@ -107,6 +115,11 @@ struct _XfdashboardFocusableInterface
 											XfdashboardFocusable *inSource,
 											const gchar *inAction,
 											ClutterEvent *inEvent);
+
+	gboolean (*focus_move_to)(XfdashboardFocusable *self,
+								XfdashboardFocusable *inSource,
+								const gchar *inAction,
+								ClutterEvent *inEvent);
 };
 
 /* Public API */
@@ -122,6 +135,8 @@ gboolean xfdashboard_focusable_set_selection(XfdashboardFocusable *self, Clutter
 ClutterActor* xfdashboard_focusable_find_selection(XfdashboardFocusable *self, ClutterActor *inSelection, XfdashboardSelectionTarget inDirection);
 gboolean xfdashboard_focusable_activate_selection(XfdashboardFocusable *self, ClutterActor *inSelection);
 
+gboolean xfdashboard_focusable_move_focus_to(XfdashboardFocusable *self);
+
 G_END_DECLS
 
 #endif	/* __LIBXFDASHBOARD_FOCUSABLE__ */
