@@ -47,6 +47,8 @@
 #include <libxfdashboard/window-tracker.h>
 #include <libxfdashboard/application.h>
 #include <libxfdashboard/compat.h>
+#include <libxfdashboard/debug.h>
+
 
 /* Gobject type for pointer arrays (GPtrArray) */
 GType xfdashboard_pointer_array_get_type(void)
@@ -288,8 +290,10 @@ static void _xfdashboard_gvalue_transform_string_enum(const GValue *inSourceValu
 		else
 		{
 			ioDestValue->data[0].v_int=0;
-			g_debug("Cannot get value for unknown enum '%s' for type %s",
-						value, g_type_name(G_VALUE_TYPE(ioDestValue)));
+			XFDASHBOARD_DEBUG(NULL, MISC,
+								"Cannot get value for unknown enum '%s' for type %s",
+								value,
+								g_type_name(G_VALUE_TYPE(ioDestValue)));
 		}
 
 	/* Release allocated resources */
@@ -324,8 +328,10 @@ static void _xfdashboard_gvalue_transform_string_flags(const GValue *inSourceVal
 		if(flagsValue) finalValue|=flagsValue->value;
 			else
 			{
-				g_debug("Cannot get value for unknown flag '%s' for type %s",
-							*entry, g_type_name(G_VALUE_TYPE(ioDestValue)));
+				XFDASHBOARD_DEBUG(NULL, MISC,
+									"Cannot get value for unknown flag '%s' for type %s",
+									*entry,
+									g_type_name(G_VALUE_TYPE(ioDestValue)));
 			}
 
 		/* Continue with next entry */
@@ -417,7 +423,7 @@ static gboolean _xfdashboard_traverse_actor_internal(ClutterActor *inActor,
 	 */
 	if(XFDASHBOARD_IS_STYLABLE(inActor))
 	{
-		score=xfdashboard_css_selector_score_matching_stylable_node(inSelector, XFDASHBOARD_STYLABLE(inActor));
+		score=xfdashboard_css_selector_score(inSelector, XFDASHBOARD_STYLABLE(inActor));
 		if(score>=0)
 		{
 			doContinueTraversal=(inCallback)(inActor, inUserData);
@@ -468,6 +474,15 @@ void xfdashboard_traverse_actor(ClutterActor *inRootActor,
 	if(!inRootActor)
 	{
 		inRootActor=CLUTTER_ACTOR(xfdashboard_application_get_stage(NULL));
+
+		/* If root actor is still NULL then no stage was found and we cannot
+		 * start the traversal.
+		 */
+		if(!inRootActor)
+		{
+			XFDASHBOARD_DEBUG(NULL, MISC, "No root actor to begin traversal at was provided and no stage available");
+			return;
+		}
 	}
 
 	/* If no selector is provider create a seletor matching all actors.
